pub fn get_git_changes(repo_path: &Path) -> Result<GitChangeSnapshot>Expand description
Quick helper to get current changes for a path.
pub fn get_git_changes(repo_path: &Path) -> Result<GitChangeSnapshot>Quick helper to get current changes for a path.