Struct GitBackend
Source pub struct GitBackend {
pub repo_path: PathBuf,
}
Default filesystem-backed Git store.
Filesystem path to the repository managed by this backend.
Construct a backend targeting the provided repository path.
Persist the provided snapshot into the fossil store.
Retrieve the latest snapshot if one exists.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.